@@ -14,7 +14,7 @@ class IsPycharmRun:
                 return func(basedir=baseDir, devices=self.deviceUrl, logdir=self.logDir)
             else:
                 print("非pycharm环境，正常调试模式")
-                return
+                return func(basedir=baseDir)
         return wrapped_function
 
     def isPycharmRun(self):
